@@ -1,7 +1,7 @@
 package PERLANCAR::Debian::Releases;
 
-our $DATE = '2017-09-08'; # DATE
-our $VERSION = '0.050'; # VERSION
+our $DATE = '2019-08-15'; # DATE
+our $VERSION = '20190815.0'; # VERSION
 
 use 5.010001;
 use strict;
@@ -18,7 +18,7 @@ our @EXPORT_OK = qw(
 our %SPEC;
 
 our $meta = {
-    summary => 'Ubuntu releases',
+    summary => 'Debian releases',
     fields => {
         version         => { pos => 0, schema => "str*", sortable => 1, summary => "Version", unique => 1 },
         code_name       => { pos => 1, schema => "str*", sortable => 1, summary => "Code name", unique => 1 },
@@ -284,6 +284,23 @@ our $data = do {
      ruby_version         => undef,
      version              => 9,
    },
+   {
+     apache_httpd_version => "2.4.38",
+     bash_version         => "5.0",
+     code_name            => "buster",
+     eoldate              => undef,
+     linux_version        => "4.19.37",
+     mariadb_version      => "10.3.15",
+     mysql_version        => "--",
+     nginx_version        => undef,
+     perl_version         => "5.28.1",
+     php_version          => "7.3.4",
+     postgresql_version   => 11.4,
+     python_version       => "3.7.3",
+     reldate              => "2019-07-06",
+     ruby_version         => undef,
+     version              => 10,
+   },
  ]
 
 };
@@ -311,7 +328,7 @@ PERLANCAR::Debian::Releases - List Debian releases
 
 =head1 VERSION
 
-This document describes version 0.050 of PERLANCAR::Debian::Releases (from Perl distribution PERLANCAR-Debian-Releases), released on 2017-09-08.
+This document describes version 20190815.0 of PERLANCAR::Debian::Releases (from Perl distribution PERLANCAR-Debian-Releases), released on 2019-08-15.
 
 =head1 SYNOPSIS
 
@@ -333,9 +350,9 @@ which was promised in 2014 and will contain extra data as well.
 
 Usage:
 
- list_debian_releases(%args) -> [status, msg, result, meta]
+ list_debian_releases(%args) -> [status, msg, payload, meta]
 
-Ubuntu releases.
+Debian releases.
 
 REPLACE ME
 
@@ -1037,7 +1054,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -1071,7 +1088,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017, 2015 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2017, 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
